ConnectOptions

Struct ConnectOptions 

pub struct ConnectOptions {
    pub agent_socket: PathBuf,
    pub user_public_key: PublicKey,
    pub hosts: Vec<String>,
}
Connection options for sending a signature request.

The options capture target host parameters and all necessary information related to authentication for both the client (client’s public key and authentication agent) and server (a list of valid and known server public keys).

Examples

use signstar_request_signature::ssh::client::ConnectOptions;

let options = ConnectOptions::new("localhost".into(), "ssh-ed25519 ...")?
    .agent_socket(std::env::var("SSH_AUTH_SOCK")?);

Fields

agent_socket: PathBuf

The path to the SSH agent socket used for the connection to user on the Signstar system(s).

user_public_key: PublicKey

The SSH public key used for the connections to user on the Signstar system(s).

hosts: Vec<String>

The list of Signstar hosts that the user can connect to.

Implementations

Source

impl ConnectOptions

pub fn agent_socket(self, agent_socket: impl Into<PathBuf>) -> Self

Sets the path to an OpenSSH agent socket for client authentication.

pub fn user_public_key( self, user_public_key: impl Into<String>, ) -> Result<Self, Error>

Sets an SSH public key of a client for SSH authentication.

Examples
use signstar_request_signature::ssh::client::ConnectOptions;

let client_pk =
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAILHCXBJYlPPkrt2WYyP3SZoMx43lDBB5QALjE762EQlc";
let options = ConnectOptions::new("localhost".into(), client_pk)?;
Errors

Returns an error if the public key is not well-formatted. This function only accepts public keys following the authorized_keys file format.

pub fn new( host: String, client_auth_public_key: impl AsRef<str>, ) -> Result<Self, Error>

Constructs a new ConnectOptions with target host and client public key.